"""
Peak.fo API Client Library for Python
Solve Turnstile, CloudFlare WAF, and AWS WAF challenges
"""

from .client import PeakClient
from .exceptions import PeakError, AuthenticationError, InsufficientBalanceError, SolveError

__version__ = "1.0.0"
__all__ = ["PeakClient", "PeakError", "AuthenticationError", "InsufficientBalanceError", "SolveError"]
