from setuptools import setup, find_packages

with open("README.md", "r", encoding="utf-8") as f:
    long_description = f.read()

setup(
    name="peakfo",
    version="1.0.0",
    description="Peak.fo API Client - Solve Turnstile, CloudFlare WAF, and AWS WAF challenges",
    long_description=long_description,
    long_description_content_type="text/markdown",
    author="Peak.fo",
    author_email="support@peak.fo",
    url="https://github.com/peakfo/peakfo-python",
    packages=find_packages(),
    install_requires=[
        "requests>=2.25.0",
    ],
    python_requires=">=3.7",
    classifiers=[
        "Development Status :: 5 - Production/Stable",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Programming Language :: Python :: 3.11",
        "Programming Language :: Python :: 3.12",
    ],
    keywords="captcha turnstile cloudflare aws waf solver",
)
